@@ -8,8 +8,8 @@ png(PNGPATH, width=600, height=350)
 hist(mtcars$disp)
 dev.off()
 
-JPGPATH <- tempfile(fileext = ".png")
+# This file comes from https://bit.ly/2P4LUO8 (cat poster on WikiPedia).
 #
-download.file("https://bit.ly/2P4LUO8", JPGPATH, quiet = TRUE)
+JPGPATH <- here::here("inst", "cats.jpg")
 
 SMTP_USERNAME = Sys.getenv("SMTP_USERNAME")
